@@ -41,6 +41,8 @@
 
 #define BLUEZQT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(BLUEZQT_NO_DEPRECATED) && !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BLUEZQT_NO_DEPRECATED
-#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
+#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
 #endif
 #ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
 #  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x57200
+#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x54300
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef BLUEZQT_DEPRECATED
-#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -115,13 +117,5 @@
 #endif
 #define BLUEZQT_DEPRECATED_VERSION_5(minor, text)      BLUEZQT_DEPRECATED_VERSION_5_##minor(text)
 #define BLUEZQT_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION(major, minor, text)
-#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* BLUEZQT_EXPORT_H */
